==> TimePrintOnPYPI-1.6.1.tar.gz: TimePrintOnPYPI-1.6.1/README.md <==
# <span style="color: #FF0000;">**TIME PRINT V1.6.1**</span>
# <span style="color: yellow;">**ENGLISH**</span><br>
<span style="color: #FF4500;">This is a python package to use write effect and more in your texts !</span><br>
# <span style="color: blue;">**FUNCTIONS**</span><br>
## <span style="color: #007FFF;">**TP(seconds,"text")**</span>
<span style="color: #E6A8D7;">You want to write "<span style="color: #87CEEB">**your_text**<span style="color: #E6A8D7;">" in <span style="color: #87CEEB">**5**<span style="color: #E6A8D7;"> seconds? just use;<br>
<span style="color: #87CEEB">**TP(5,"your_text")**<span style="color: #E6A8D7;"> !<br>
<span style="color: #0F52BA">Formats: seconds: int,"text":str<br>

## <span style="color: #007FFF;">**P("text")**</span>
<span style="color: #E6A8D7;">You don't want to wait until it writes bla bla seconds ?<br>
it just goes write effect and its fast (very fast)<br>
Example;<br>
<span style="color: #87CEEB">**P("TEXT")**<br>
<span style="color: #0F52BA">format: "text":str<br>

## <span style="color: #007FFF;">**Timetag(format:str)<br>TIME TAG ONLY SUPPORTS (TR) LANGUAGE. ALL RETRUNS WILL BE TURKISH ALL THIS STUFF IS EXAMPLE**</span>
<span style="color: #E6A8D7;">Its not very cool thing but i added,Don't have to much talk just look ex.<br>

<span style="color: #E6A8D7;">Example format usages;<br>

<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M")<span style="color: #E6A8D7;">" Returns --> 12:56 = <span style="color: #87CEEB;">(Hours:Minutes)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M:%S")<span style="color: #E6A8D7;">" Returns --> 12:56:24 = <span style="color: #87CEEB;">(Hours:Minutes:Seconds)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%d.%m.%y")<span style="color: #E6A8D7;">" Returns --> 10.02.2023 = <span style="color: #87CEEB;">(Day.Month.Year)
<br>
### <span style="color: red;">**ALL USAGES:**

<span style= "color: orange;">`%Y`<span style="color: cyan;"> =  4-digit year (e.g., 2023) <br>
<span style= "color: orange;">`%y` <span style="color: cyan;">= 0 2-digit year (e.g., 23)<br>
<span style= "color: orange;">`%m` <span style="color: cyan;">= Month number (01-12)<br>
<span style= "color: orange;">`%B` <span style="color: cyan;">= Full month name (e.g., January, February)<br>
<span style= "color: orange;">`%b` <span style="color: cyan;">= Abbreviated month name (e.g., Jan, Feb)<br>
<span style= "color: orange;">`%d` <span style="color: cyan;">= Day of the month (01-31)<br>
<span style= "color: orange;">`%A` <span style="color: cyan;">= Full weekday name (e.g., Monday, Tuesday)<br>
<span style= "color: orange;">`%a` <span style="color: cyan;">= Abbreviated weekday name (e.g., Mon, Tue)<br>
<span style= "color: orange;">`%H` <span style="color: cyan;">= Hour in 24-hour format (00-23)<br>
<span style= "color: orange;">`%I` <span style="color: cyan;">= Hour in 12-hour format (01-12)<br>
<span style= "color: orange;">`%M` <span style="color: cyan;">= Minute (00-59)<br>
<span style= "color: orange;">`%S` <span style="color: cyan;">= Second (00-59)<br>
<span style= "color: orange;">`%p` <span style="color: cyan;">= AM/PM indicator<br>
<span style= "color: orange;">`%Z` <span style="color: cyan;">= Timezone name<br>
<span style= "color: orange;">`%j` <span style="color: cyan;">= Day of the year (001-366)<br>
<span style= "color: orange;">`%W` <span style="color: cyan;">= Week number of the year (Sunday as the first day, 00-53)<br>

<span style="color: #0F52BA">It uses strftime package from time.<br>




## <span style="color: #007FFF;">**info()**</span>
<span style="color: #E6A8D7;">just info about package.<br>
My name, My email and project github repostory



# <span style="color: yellow;">**TURKISH**</span><br>
<span style="color: #FF4500;">Bu mesajlarınızda yazı efekti ve daha fazlasını kullanabileceğiniz bir python paketidir!</span><br>

# <span style="color: blue;">**FONKSIYONLAR**</span><br>
## <span style="color: #007FFF;">**TP(seconds,"text")**</span>
<span style="color: #87CEEB">**MESAJ**<span style="color: #E6A8D7;"> Mesajınızı <span style="color: #87CEEB">**5**<span style="color: #E6A8D7;"> Saniyede yazmakmı istiyorsunuz? şunu kullanın;<br>
<span style="color: #87CEEB">**TP(5,"MESAJ")**<br>
<span style="color: #0F52BA">Formatlar: saniye: int,"metin":str<br>

## <span style="color: #007FFF;">**P("text")**</span>
<span style="color: #E6A8D7;">Bilmem kaç saniye boyunca yazmasını beklemek istemiyormusunuz?<br>
bu mesajınızı hızlı (çok hızlı) bir şekilde yazar.<br>
Kullanım:<br>
<span style="color: #87CEEB">**P("MESAJINIZ")**<br>

<span style="color: #0F52BA">Format: "metin":str<br>

## <span style="color: #007FFF;">**Timetag(format:str)**</span>
<span style="color: #E6A8D7;">Çok havalı bir şey değil ama yinede ekledim. örneğe bakın.<br>

<span style="color: #E6A8D7;">Örnek format kullanımı:<br>

<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M")<span style="color: #E6A8D7;">" 12:56 Olarak Geri Döner --> <span style="color: #87CEEB;">(Saat:Dakika)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M:%S")<span style="color: #E6A8D7;">" 12:56:24 Olarak Geri Döner --> <span style="color: #87CEEB;">(Saat:Dakika:Saniye)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%d.%m.%y")<span style="color: #E6A8D7;">" 10.02.2023 Olarak Geri Döner --> <span style="color: #87CEEB;">(Gün.Ay.Yıl)<br>
### <span style="color: red;">**TÜM KULLANIMLAR:**<br>

<span style="color: orange;">`%Y` <span style="color: cyan;">= 4 haneli yıl (örn. 2023)<br>
<span style="color: orange;">`%y` <span style="color: cyan;">= 2 haneli yıl (örn. 23)<br>
<span style="color: orange;">`%m` <span style="color: cyan;">= Ay numarası (01-12 arası)<br>
<span style="color: orange;">`%B` <span style="color: cyan;">= Tam ay adı (örn. Ocak, Şubat)<br>
<span style="color: orange;">`%b` <span style="color: cyan;">= Kısaltılmış ay adı (örn. Oca, Şub)<br>
<span style="color: orange;">`%d` <span style="color: cyan;">= Ayın günü (01-31 arası)<br>
<span style="color: orange;">`%A` <span style="color: cyan;">= Tam hafta günü adı (örn. Pazartesi, Salı)<br>
<span style="color: orange;">`%a` <span style="color: cyan;">= Kısaltılmış hafta günü adı (örn. Paz, Sal)<br>
<span style="color: orange;">`%H` <span style="color: cyan;">= 24 saatlik formatla saat (00-23 arası)<br>
<span style="color: orange;">`%I` <span style="color: cyan;">= 12 saatlik formatla saat (01-12 arası)<br>
<span style="color: orange;">`%M` <span style="color: cyan;">= Dakika (00-59 arası)<br> 
<span style="color: orange;">`%S` <span style="color: cyan;">= Saniye (00-59 arası)<br>
<span style="color: orange;">`%p` <span style="color: cyan;">= ÖÖ/ÖS göstergesi<br>
<span style="color: orange;">`%Z` <span style="color: cyan;">= Zaman dilimi<br>
<span style="color: orange;">`%j` <span style="color: cyan;">= Yılın günü (001-366 arası)<br>
<span style="color: orange;">`%W` <span style="color: cyan;">= Yılın hafta numarası (Pazar günü başlangıç, 00-53 arası)<br>

<span style="color: #0F52BA">Time modülünden strftime paketini kullanır.<br>


## <span style="color: #007FFF;">**info()**</span>
<span style="color: #E6A8D7;">Paket hakkında bilgi<br>
Adım, email adresim ve projenin github sayfası.

==> TimePrintOnPYPI-1.7.tar.gz: TimePrintOnPYPI-1.7/README.md <==
# <span style="color: #FF0000;">**TIME PRINT V1.7**</span>
# <span style="color: yellow;">**ENGLISH**</span><br>
<span style="color: #FF4500;">This is a python package to use write effect and more in your texts !</span><br>
# <span style="color: blue;">**FUNCTIONS**</span><br>
## <span style="color: #007FFF;">**TP(seconds,"text")**</span>
<span style="color: #E6A8D7;">You want to write "<span style="color: #87CEEB">**your_text**<span style="color: #E6A8D7;">" in <span style="color: #87CEEB">**5**<span style="color: #E6A8D7;"> seconds? just use;<br>
<span style="color: #87CEEB">**TP(5,"your_text")**<span style="color: #E6A8D7;"> !<br>
<span style="color: #0F52BA">Formats: seconds: int,"text":str<br>

## <span style="color: #007FFF;">**P("text")**</span>
<span style="color: #E6A8D7;">You don't want to wait until it writes bla bla seconds ?<br>
it just goes write effect and its fast (very fast)<br>
Example;<br>
<span style="color: #87CEEB">**P("TEXT")**<br>
<span style="color: #0F52BA">format: "text":str<br>

## <span style="color: #007FFF;">**Timetag(format:str)<br>TIME TAG ONLY SUPPORTS (TR) LANGUAGE. ALL RETURNS WILL BE TURKISH ALL THIS STUFF IS EXAMPLE**</span>
<span style="color: #E6A8D7;">Its not very cool thing but i added,Don't have to much talk just look ex.<br>

<span style="color: #E6A8D7;">Example format usages;<br>

<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M")<span style="color: #E6A8D7;">" Returns --> 12:56 = <span style="color: #87CEEB;">(Hours:Minutes)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M:%S")<span style="color: #E6A8D7;">" Returns --> 12:56:24 = <span style="color: #87CEEB;">(Hours:Minutes:Seconds)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%d.%m.%y")<span style="color: #E6A8D7;">" Returns --> 10.02.2023 = <span style="color: #87CEEB;">(Day.Month.Year)
<br>
### <span style="color: red;">**ALL USAGES:**

<span style= "color: orange;">`%Y`<span style="color: cyan;"> =  4-digit year (e.g., 2023) <br>
<span style= "color: orange;">`%y` <span style="color: cyan;">= 0 2-digit year (e.g., 23)<br>
<span style= "color: orange;">`%m` <span style="color: cyan;">= Month number (01-12)<br>
<span style= "color: orange;">`%B` <span style="color: cyan;">= Full month name (e.g., January, February)<br>
<span style= "color: orange;">`%b` <span style="color: cyan;">= Abbreviated month name (e.g., Jan, Feb)<br>
<span style= "color: orange;">`%d` <span style="color: cyan;">= Day of the month (01-31)<br>
<span style= "color: orange;">`%A` <span style="color: cyan;">= Full weekday name (e.g., Monday, Tuesday)<br>
<span style= "color: orange;">`%a` <span style="color: cyan;">= Abbreviated weekday name (e.g., Mon, Tue)<br>
<span style= "color: orange;">`%H` <span style="color: cyan;">= Hour in 24-hour format (00-23)<br>
<span style= "color: orange;">`%I` <span style="color: cyan;">= Hour in 12-hour format (01-12)<br>
<span style= "color: orange;">`%M` <span style="color: cyan;">= Minute (00-59)<br>
<span style= "color: orange;">`%S` <span style="color: cyan;">= Second (00-59)<br>
<span style= "color: orange;">`%p` <span style="color: cyan;">= AM/PM indicator<br>
<span style= "color: orange;">`%Z` <span style="color: cyan;">= Timezone name<br>
<span style= "color: orange;">`%j` <span style="color: cyan;">= Day of the year (001-366)<br>
<span style= "color: orange;">`%W` <span style="color: cyan;">= Week number of the year (Sunday as the first day, 00-53)<br>

<span style="color: #0F52BA">It uses strftime package from time.<br>




## <span style="color: #007FFF;">**info()**</span>
<span style="color: #E6A8D7;">just info about package.<br>
My name, My email and project github repostory



# <span style="color: yellow;">**TURKISH**</span><br>
<span style="color: #FF4500;">Bu mesajlarınızda yazı efekti ve daha fazlasını kullanabileceğiniz bir python paketidir!</span><br>

# <span style="color: blue;">**FONKSIYONLAR**</span><br>
## <span style="color: #007FFF;">**TP(seconds,"text")**</span>
<span style="color: #87CEEB">**MESAJ**<span style="color: #E6A8D7;"> Mesajınızı <span style="color: #87CEEB">**5**<span style="color: #E6A8D7;"> Saniyede yazmakmı istiyorsunuz? şunu kullanın;<br>
<span style="color: #87CEEB">**TP(5,"MESAJ")**<br>
<span style="color: #0F52BA">Formatlar: saniye: int,"metin":str<br>

## <span style="color: #007FFF;">**P("text")**</span>
<span style="color: #E6A8D7;">Bilmem kaç saniye boyunca yazmasını beklemek istemiyormusunuz?<br>
bu mesajınızı hızlı (çok hızlı) bir şekilde yazar.<br>
Kullanım:<br>
<span style="color: #87CEEB">**P("MESAJINIZ")**<br>

<span style="color: #0F52BA">Format: "metin":str<br>

## <span style="color: #007FFF;">**Timetag(format:str)**</span>
<span style="color: #E6A8D7;">Çok havalı bir şey değil ama yinede ekledim. örneğe bakın.<br>

<span style="color: #E6A8D7;">Örnek format kullanımı:<br>

<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M")<span style="color: #E6A8D7;">" 12:56 Olarak Geri Döner --> <span style="color: #87CEEB;">(Saat:Dakika)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M:%S")<span style="color: #E6A8D7;">" 12:56:24 Olarak Geri Döner --> <span style="color: #87CEEB;">(Saat:Dakika:Saniye)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%d.%m.%y")<span style="color: #E6A8D7;">" 10.02.2023 Olarak Geri Döner --> <span style="color: #87CEEB;">(Gün.Ay.Yıl)<br>
### <span style="color: red;">**TÜM KULLANIMLAR:**<br>

<span style="color: orange;">`%Y` <span style="color: cyan;">= 4 haneli yıl (örn. 2023)<br>
<span style="color: orange;">`%y` <span style="color: cyan;">= 2 haneli yıl (örn. 23)<br>
<span style="color: orange;">`%m` <span style="color: cyan;">= Ay numarası (01-12 arası)<br>
<span style="color: orange;">`%B` <span style="color: cyan;">= Tam ay adı (örn. Ocak, Şubat)<br>
<span style="color: orange;">`%b` <span style="color: cyan;">= Kısaltılmış ay adı (örn. Oca, Şub)<br>
<span style="color: orange;">`%d` <span style="color: cyan;">= Ayın günü (01-31 arası)<br>
<span style="color: orange;">`%A` <span style="color: cyan;">= Tam hafta günü adı (örn. Pazartesi, Salı)<br>
<span style="color: orange;">`%a` <span style="color: cyan;">= Kısaltılmış hafta günü adı (örn. Paz, Sal)<br>
<span style="color: orange;">`%H` <span style="color: cyan;">= 24 saatlik formatla saat (00-23 arası)<br>
<span style="color: orange;">`%I` <span style="color: cyan;">= 12 saatlik formatla saat (01-12 arası)<br>
<span style="color: orange;">`%M` <span style="color: cyan;">= Dakika (00-59 arası)<br> 
<span style="color: orange;">`%S` <span style="color: cyan;">= Saniye (00-59 arası)<br>
<span style="color: orange;">`%p` <span style="color: cyan;">= ÖÖ/ÖS göstergesi<br>
<span style="color: orange;">`%Z` <span style="color: cyan;">= Zaman dilimi<br>
<span style="color: orange;">`%j` <span style="color: cyan;">= Yılın günü (001-366 arası)<br>
<span style="color: orange;">`%W` <span style="color: cyan;">= Yılın hafta numarası (Pazar günü başlangıç, 00-53 arası)<br>

<span style="color: #0F52BA">Time modülünden strftime paketini kullanır.<br>


## <span style="color: #007FFF;">**info()**</span>
<span style="color: #E6A8D7;">Paket hakkında bilgi<br>
Adım, email adresim ve projenin github sayfası.
